import { AbstractControl, VALID } from './abstract-control';
export class FormControl extends AbstractControl {
    constructor(formState, validators, asyncValidator) {
        super(validators !== null && validators !== void 0 ? validators : null, asyncValidator !== null && asyncValidator !== void 0 ? asyncValidator : null);
        Object.defineProperty(this, "defaultState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_value", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_status", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: VALID
        });
        this.defaultState = formState;
        this._applyFormState(formState);
        this.updateValueAndValidity(true);
    }
    setValue(value, onlySelf) {
        this._value = value;
        this.updateValueAndValidity(onlySelf);
    }
    patchValue(value, onlySelf) {
        this.setValue(value, onlySelf);
    }
    reset(formState = this.defaultState, onlySelf) {
        this._applyFormState(formState);
        this.markAsPristine(onlySelf);
        this.setValue(this.value, onlySelf);
    }
    _updateValue() { }
    _forEachChild() { }
    _anyControls() {
        return false;
    }
    _allControlsDisabled() {
        return this.disabled;
    }
    _isFormStateObject(formState) {
        return (typeof formState === 'object' &&
            formState !== null &&
            Object.keys(formState).length === 2 &&
            'value' in formState &&
            'disabled' in formState);
    }
    _applyFormState(formState) {
        if (this._isFormStateObject(formState)) {
            this._value = formState.value;
            formState.disabled ? this.disable(true) : this.enable(true);
        }
        else {
            this._value = formState;
        }
    }
}
