import { useMemo, useRef } from 'react';
import { useId, useUnmount } from '@react-devui/hooks';
import { usePrefixConfig } from '../components/root';
const MAX_INDEX_MANAGER = {
    record: {},
    getMaxIndex(id) {
        let maxZIndex = 0;
        Object.values(this.record).forEach((num) => {
            maxZIndex = Math.max(maxZIndex, num);
        });
        maxZIndex += 1;
        this.record[id] = maxZIndex;
        return maxZIndex;
    },
    deleteRecord(id) {
        delete this.record[id];
    },
};
export function useMaxIndex(condition) {
    const dPrefix = usePrefixConfig();
    const dataRef = useRef({});
    const id = useId();
    const zIndex = useMemo(() => {
        MAX_INDEX_MANAGER.deleteRecord(id);
        if (condition) {
            const maxZIndex = MAX_INDEX_MANAGER.getMaxIndex(id);
            return `calc(var(--${dPrefix}zindex-fixed) + ${maxZIndex})`;
        }
        return dataRef.current.prevIndex;
    }, [condition, dPrefix, id]);
    dataRef.current.prevIndex = zIndex;
    useUnmount(() => {
        MAX_INDEX_MANAGER.deleteRecord(id);
    });
    return zIndex;
}
